﻿
assert(TooltipExchange, "TooltipExchange not found!")

-------------------------------------------------------------------------------
-- Locals
-------------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("TooltipExchangeLoot")
local dewdrop = AceLibrary("Dewdrop-2.0")

-------------------------------------------------------------------------------
-- Localization
-------------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Raid Loot"] = true,
	["Raid instance bosses drop lists."] = true,
} end)

-------------------------------------------------------------------------------
-- Declaration
-------------------------------------------------------------------------------

local instanceLoot = {
	{ header = L["Raid Loot"] },
	{ text = "Azeroth", zone = "World Bosses", bosses = { "Azuregos", "Emeriss", "Lethon", "Lord Kazzak", "Taerar", "Ysondre" } },
	{ zone = "Zul'Gurub", bosses = { "Bloodlord Mandokir", "Gri'lek", "Hakkar", "Hazza'rah", "High Priest Thekal", "High Priest Venoxis", "High Priestess Arlokk", "High Priestess Jeklik", "High Priestess Mar'li", "Jin'do the Hexxer", "Renataki", "Wushoolay" } },
	{ zone = "Ruins of Ahn'Qiraj", bosses = { "Ayamiss the Hunter", "Buru the Gorger", "General Rajaxx", "Kurinnaxx", "Moam", "Ossirian the Unscarred" } },
	{ zone = "Onyxia's Lair", bosses = { "Onyxia" } },
	{ zone = "Molten Core", bosses = { "Baron Geddon", "Garr", "Gehennas", "Golemagg the Incinerator", "Lucifron", "Magmadar", "Majordomo Executus", "Ragnaros", "Shazzrah", "Sulfuron Harbinger" } },
	{ zone = "Blackwing Lair", bosses = { "Broodlord Lashlayer", "Chromaggus", "Ebonroc", "Firemaw", "Flamegor", "Nefarian", "Razorgore the Untamed", "Vaelastrasz the Corrupt" } },
	{ zone = "Ahn'Qiraj", bosses = { "Battleguard Sartura", "C'Thun", "Emperor Vek'lor", "Emperor Vek'nilash", "Fankriss the Unyielding", "Lord Kri", "Ouro", "Princess Huhuran", "Princess Yauj", "The Prophet Skeram", "Vem", "Viscidus" } },
	{ zone = "Naxxramas", bosses = { "Anub'Rekhan", "Gluth", "Gothik the Harvester", "Grand Widow Faerlina", "Grobbulus", "Heigan the Unclean", "Highlord Mograine", "Instructor Razuvious", "Kel'Thuzad", "Lady Blaumeux", "Loatheb", "Maexxna", "Noth the Plaguebringer", "Patchwerk", "Sapphiron", "Sir Zeliek", "Thaddius" } },
	{ header = " " },
	{ text = "Outland", zone = "World Bosses", bosses = { "Doom Lord Kazzak", "Doomwalker" } },
	{ zone = "Karazhan", bosses = { "Attumen the Huntsman", "Hyakiss the Lurker", "Julianne", "Maiden of Virtue", "Moroes", "Netherspite", "Nightbane", "Prince Malchezaar", "Romulo", "Shade of Aran", "Terestian Illhoof", "The Big Bad Wolf", "The Crone", "The Curator" } },
	{ zone = "Gruul's Lair", bosses = { "High King Maulgar", "Gruul the Dragonkiller" } },
	{ zone = "Magtheridon's Lair", bosses = { "Magtheridon" } },
	{ zone = "Serpentshrine Cavern", bosses = { "Fathom-Lord Karathress", "Hydross the Unstable", "Lady Vashj", "Leotheras the Blind", "Morogrim Tidewalker", "The Lurker Below" } },
}

TooltipExchangeLoot = TooltipExchange:NewModule(L["Raid Loot"])
TooltipExchangeLoot.notToggable = true

TooltipExchangeLoot.commands = {
	raidLoot = {
		type = "group",
		name = L["Raid Loot"],
		desc = L["Raid instance bosses drop lists."],
		order = 15,
		args = {},
	},
}

TooltipExchangeLoot.revision = tonumber(string.sub("$Revision: 30030 $", 12, -3))

-------------------------------------------------------------------------------
-- Main
-------------------------------------------------------------------------------

function TooltipExchangeLoot:OnInitialize()
	self:CreateStaticMenu()
end

function TooltipExchangeLoot:OnEnable()

end

function TooltipExchangeLoot:OnDisable()

end

-------------------------------------------------------------------------------
-- Dynamic Menu
-------------------------------------------------------------------------------

function TooltipExchangeLoot:CreateStaticMenu()
	local a, o = self.commands.raidLoot.args, 100

	for _, v in ipairs(instanceLoot) do
		if v.header then
			a["header" .. o] = {
				type = "header",
				order = o,
				name = v.header,
			}
		elseif v.zone and v.bosses then
			local zz = string.gsub(v.text or v.zone, "[^%a]", "")

			a[zz] = {
				type = "group",
				name = v.text or v.zone,
				desc = v.text or v.zone,
				order = o,
				args = {
					header = {
						type = "header",
						order = 1,
						name = v.text or v.zone,
					},
				},
			}

			for _, b in ipairs(v.bosses) do
				local z = v.zone
				local bb = string.gsub(b, "[^%a]", "")

				a[zz].args[bb] = {
					type = "execute",
					name = b,
					desc = b,
					func = function()
						self:TriggerEvent("TooltipExchange_PeriodicResults", "InstanceLoot." .. z .. "." .. b)
						dewdrop:Close()
					end,
				}
			end
		end

		o = o + 1
	end
end
